@@ -9,6 +9,8 @@ from pyblog.colored_print import printDebug
 
 # check if pandoc exists
 panDoc = True
+pandocFmt = '+tex_math_dollars'+'+raw_tex'+'+latex_macros'
+
 try:
     subprocess.call(["pandoc", '--version']
             , stdout=subprocess.PIPE
@@ -27,27 +29,39 @@ def decodeText(text):
 
 def markdownToHtml(content, convertor='pandoc'):
     global panDoc
+    global pandocFmt
+
+    if len(content) < 1:
+        printDebug("WARN", "No content to convert using pandoc")
+        return None 
+
     if panDoc:
         printDebug("DEBUG", "Using pandoc for markdown -> html")
-        cmd = ["pandoc", "-f", "markdown", "-t", "html"]
+        cmd = ["pandoc", "--mathjax", "--highlight-style=pygments"
+                , "-f", 'markdown'+pandocFmt, "-t", "html"]
         p = subprocess.Popen(cmd
                 , stdin = subprocess.PIPE
                 , stdout = subprocess.PIPE
                 )
         p.stdin.write(content)
-        content = p.communicate()[0]
-        return decodeText(content)
+        c = p.communicate()[0]
+        if len(c) < 2:
+            printDebug("WARN", "Seems like pandoc failed to work")
+            return None
+        printDebug("LOG", "\n\n Converted text \n {}".format(c))
+        return decodeText(c)
     # else use inbuild html2text.py 
     else:
-        printDebug("DEBUG", "Using python-markdown for html -> markdown")
+        printDebug("DEBUG", "Using python-markdown for markdown -> html")
         return markdown.markdown(decodeText(content))
 
 
 def htmlToMarkdown(content, convertor='pandoc'):
     global panDoc
+    global pandocFmt
     if panDoc and convertor == 'pandoc':
         logging.debug("using pandoc for html -> markdown")
-        cmd = ["pandoc", "-t", "markdown", "-f", "html"]
+        cmd = ["pandoc", "-t", 'markdown'+pandocFmt, "-f", "html"]
         p = subprocess.Popen(cmd
                 , stdin = subprocess.PIPE
                 , stdout = subprocess.PIPE
@@ -57,7 +71,6 @@ def htmlToMarkdown(content, convertor='pandoc'):
         return decodeText(content)
     # Use markdown package to convert markdown to html
     else:
-        logging.debug("Using html2text for html -> markdown")
         printDebug("INFO", "html2text for html -> markdown")
         h = html2text.HTML2Text()
         content = h.handle(decodeText(content))
@@ -89,9 +102,9 @@ def metadataDict(txt):
     for c in ["title", 'type', "layout", "status", "id", "published"
                 , "categories", "tags"]:
         pat = re.compile(r'{0}\s*:\s*(?P<name>.+)'.format(c), re.IGNORECASE)
-        m = pat.find(txt)
-        for i in m:
-            mdict[c] = i
+        m = pat.search(txt)
+        if m:
+            mdict[c] = m.group('name')
     return mdict
 
 def getMetadata(txt):
@@ -153,3 +166,8 @@ def formatContent(txt, fmt):
     return content
 
 
+if __name__ == "__main__":
+    txt = open("./tests/latex.txt", "r").read()
+    pat = re.compile(r'\$\$(.+?)\$\$', re.DOTALL)
+    print pat.sub(r'$latex \1$', txt)
+
