@@ -19,7 +19,7 @@ import logging
 import pyblog.formatter as formatter
 from pyblog.colored_print import printDebug
 
-logging.basicConfig(filname='.wordpress.log')
+logging.basicConfig(filname=os.environ['HOME']+'.wordpress.log')
 
 
 deliminator = '---'
@@ -52,8 +52,9 @@ class Wordpress:
         try:
             self.updatePost(post, txt)
         except Exception as e:
-            logging.warning("Failed to send post to wordpress")
-            logging.debug("Error was {0}".format(e))
+            printDebug("WARN", "Failed to send post to wordpress")
+            printDebug("DEBUG", "Error was {0}".format(e))
+            return 
 
         printDebug("INFO", "Post sent successfully")
         # Now download the sent post and save it.
@@ -105,15 +106,14 @@ class Wordpress:
         try:
             id = post.id 
         except AttributeError:
-            id = mdict.get('id')
-            if not id :
+            id = mdict.get('id', None)
+            if not id:
                 printDebug("ERROR"
                         , "This looks like a new post, use --post option"
                         )
                 sys.exit(0)
-            id = id[0]
         post.id = id
-        title = ' '.join(mdict['title'])
+        title = mdict['title']
         post.title = title.strip()
     
         self.attachType(mdict, post)
@@ -179,25 +179,34 @@ class Wordpress:
             content = formatter.htmlToHtml(content)
         elif self.format == "markdown":
             content = formatter.markdownToHtml(content)
-            post.content = content
+            # Fix the math class 
+            pat = re.compile(r'\<span\s+class\=\"math\"\>\\\((.+?)\\\)\<\/span\>'
+                    , re.DOTALL)
+            for m in pat.findall(content):
+                printDebug("INFO", "Latex expression: ", m) 
+            content = pat.sub(r'$latex \1$', content)
+                
+            post.content = content.encode('utf-8')
         else:
-            post.content = content
+            post.content = content.encode('utf-8')
 
         #logFile = os.path.join(self.blogDir, "sent_html") 
         #printDebug("DEBUG", "Logging content into %s" % logFile)
         #with open(logFile, "w") as f:
             #f.write(post.content.encode('utf-8'))
 
-        logging.debug(
-                "[I] Sending post : {0} : {1}.".format(post.id, post.title)
+        printDebug("STEP"
+                , "Sending post : {0} : {1}.".format(post.id, post.title)
                 )
         try:
             self.wp.call(EditPost(post.id, post))
         except Exception as e:
-            logging.debug("[DEBUG] I was trying to update but failed")
-            logging.debug(" + You sure that this post exist on the blog.")
-            logging.debug("Error was : {0}".format(e))
-            raise UserWarning, "Failed to update post", e
+            printDebug("DEBUG", "I was trying to update but failed")
+            printDebug("INFO", "Error was : {0}".format(e))
+            printDebug("DEBUG", "Content of post was written to log.txt file")
+            with open("log.txt", "w") as f:
+                f.write(post.content)
+            sys.exit(0)
     
     def writeContent(self, fH, content, format):
         """Write content to file.
